django-relatives
================

django-relatives provides various utilites that make it easy to link related
objects in the Django admin site.

Contents
--------

.. toctree::
   :maxdepth: 2

   usage
   api

Contributing
------------

Visit the project `on Github`_ to view the source, submit issues and pull
requests.

.. _on github: https://github.com/treyhunner/django-relatives

Examples
--------

Turn read-only foreign key fields into hyperlinks
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. figure:: images/object_edit_link_example.png

Link to child objects in the sidebar
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. figure:: images/related_objects_example.png

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

